package com.tocea.easycoverage.framework.api;

/**
 * 
 * Interface for classes providing instances to checkers. An instance provider
 * may not be able to provide an instance for any given class, but if canProvide
 * returns true for a class, an instance should be return by getInstance for
 * this class.
 * 
 * @author Romain Delamare
 * 
 */
public interface IInstanceProvider {

	/**
	 * Creates an instance of the specified class. Returns null if an instance
	 * cannot be created.
	 * 
	 * @param clazz
	 *            the clazz for which an instance must be created
	 * @return an instance of clazz
	 */
	public <T> T getInstance(Class<T> clazz);

	/**
	 * Checks if an instance can be created for the specified class.
	 * 
	 * @param clazz
	 *            a class
	 * @return true if an instance of clazz can be create by this instance
	 *         provider
	 */
	public <T> boolean canProvide(Class<T> clazz);

}
